

# Maghilchi
 Maghilchi is a interpreted language with a natural language-like syntax with tamil words.

# Why Maghilchi?
In Tamil Nadu(India), There are millions of students who studies in tamil medium schools or schools who use tamil as medium of teaching subjects. Many of them wants to learn coding since most of the proggraming language is in English they see that as barrier. So I decided to make proggraming language that use tamil in syntax instead of English which will eventually breaks that language barrier. This will help many students from tamil mediums to become a good programmer in the future, Even some of them might use proggraming skills to create product to solve real life problems.

# Goals for Maghilchi:
1. Simple and natural language based Programming language
2. Hassle Free Installation and configuration so that anyone can install easily and use!
3. Need to add various functionality such as GUI Creation, networking support etc which will encourage kids to create games etc
4. Memory Safe programming language for security of applications.

# Future Plans for Maghilchi
1. Create a package manager to install packages and remove packages for maghilchi

## How to Access Source Code of Maghilchi.

Until first version of stable release source code of Maghilchi will be closed source as I need to do lots of code cleanup as code is clumsy as of now.

## Usage/Examples

Copmiler Usage:

```
mg++ Hello_world.mgpp

```

Code :
```
அச்சிடு "Hello-World"

```
Simple Arithmetic Using maghilchi Code :

```
பொறுத்து a செய்ய 1
பொறுத்து b செய்ய 1
கூட்டு a செய்ய b
கூட்டு 1 செய்ய b
அச்சிடு b
அச்சிடு a
```

Users can also Use Maghilchi IDE instead for commandline 
Which you can download from following repository and Maghichi IDE requires you to install mg++ via Pypi




## Installation

```bash
pip3 install maghilchi

```
Will add standalone installation binary in stable release.


## Authors

- [@Harish](https://github.com/harishsg99)



## Acknowledgements

I like to thank following people for their books and courses
1.  Dmitry Soshnikov for this course https://www.udemy.com/course/essentials-of-interpretation/ 
2.  David for his parser design for Natural language.
3.  C++ and G++ (Name of Maghilchi interpreter and file format inspired from C++)
